@@ -8,14 +8,14 @@
     ## Author: Sebastian Luque
     ## --------------------------------------------------------------------
     if (!is(x, "TDRcalibrate")) stop ("x needs to be a TDRcalibrate object")
-    act <- getGAct(x, "trip.act")
+    act <- getGAct(x, "activity")
     diveid <- getDAct(x, "dive.id")
 
     if (ignoreZ) {
         tt <- getTime(getTDR(x))
         interval <- getDtime(getTDR(x))
         act[act == "Z"] <- "L"
-        attlist <- getAct(tt, act, interval) # recalculate
+        attlist <- rleActivity(tt, act, interval) # recalculate
         phaseid <- as.numeric(attlist[[1]])  # what phase.id is now
     } else {
         attlist <- getGAct(x)
